@@ -302,9 +302,7 @@ class HardhatProvider(SubprocessProvider, Web3Provider, TestProviderAPI):
         return self._make_request("evm_setBlockGasLimit", [hex(gas_limit)]) is True
 
     def set_timestamp(self, new_timestamp: int):
-        pending_timestamp = self.get_block("pending").timestamp
-        seconds_to_increase = new_timestamp - pending_timestamp
-        self._make_request("evm_increaseTime", [seconds_to_increase])
+        self._make_request("evm_setNextBlockTimestamp", [new_timestamp])
 
     def mine(self, num_blocks: int = 1):
         # NOTE: Request fails when given numbers with any left padded 0s.
@@ -507,7 +505,10 @@ class HardhatForkProvider(HardhatProvider):
 
         return cmd
 
-    def reset_fork(self):
-        self._make_request(
-            "hardhat_reset", [{"jsonRpcUrl": self.fork_url, "blockNumber": self.fork_block_number}]
-        )
+    def reset_fork(self, block_number: Optional[int] = None):
+        forking_params: Dict[str, Union[str, int]] = {"jsonRpcUrl": self.fork_url}
+        block_number = block_number if block_number is not None else self.fork_block_number
+        if block_number is not None:
+            forking_params["blockNumber"] = block_number
+
+        return self._make_request("hardhat_reset", [{"forking": forking_params}])
